package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````@!X```````!``````````$"Q````
M`````````$``.``)`$``&P`:``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````#R?````````/)\`````````
M`"````````$````&````T*L```````#0JR```````-"K(```````4`0`````
M``#8%```````````(````````@````8```#HJP```````.BK(```````Z*L@
M``````#@`0```````.`!````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````$)@````````0F````````!"8````````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````-"K````````T*L@``````#0JR``
M`````#`$````````,`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50##P%E$P!NK`FOO@N,R(7\U1$*WE!$```!&````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA%N@0""@````!&````
M2@```$X```!/````50```%8```!8````7````%T`````````7P```&(```!C
M````9```````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\"ZXY)\PN4_+/JA;&"S`8MO:PE#UF:OS&;%N9Q`0D75
M[,2)!9"(!W#3.?*+'`T4XI[:S>.>,V+;[0PZEPM6I)N6I]VC:W^IG)OAIP(*
M"HH05Z/@^TD```````````````````````````````````````````,`"@!@
M&@``````````````````)0$``!(`````````````````````````[`$``!(`
M````````````````````````:P(``!(`````````````````````````0`(`
M`!(`````````````````````````$0```"``````````````````````````
M<@(``!(`````````````````````````]P(``!(`````````````````````
M````R````!(`````````````````````````AP(``!(`````````````````
M````````EP$``!(`````````````````````````WP(``!(`````````````
M````````````UP(``!(`````````````````````````F````!(`````````
M````````````````N`,``!(`````````````````````````(`$``!(`````
M````````````````````HP(``!(`````````````````````````E0(``!(`
M````````````````````````6@(``!(`````````````````````````\`(`
M`!(`````````````````````````#0,``!(`````````````````````````
M>P$``!(`````````````````````````20$``!(`````````````````````
M````U@```!(`````````````````````````Q0$``!(`````````````````
M````````&0(``!(`````````````````````````40(``!(`````````````
M````````````*0(``!(`````````````````````````2`(``!(`````````
M````````````````L@$``!(`````````````````````````@`(``!(`````
M````````````````````YP$``!(`````````````````````````40,``!(`
M````````````````````````2@,``!(`````````````````````````5P$`
M`!(```````````````````````````,``!(`````````````````````````
M+0```"``````````````````````````MP(``!(`````````````````````
M````>````!(`````````````````````````!0(``!(`````````````````
M````````O@$``!(`````````````````````````IP```!(`````````````
M````````````LP```!(`````````````````````````<`$``!(`````````
M````````````````-@$``!(`````````````````````````:@```!(`````
M````````````````````*@$``!(`````````````````````````O@(``!(`
M````````````````````````IP$``!(`````````````````````````!`$`
M`!(`````````````````````````>`(``!(`````````````````````````
MX`$``!(`````````````````````````.P,``!(`````````````````````
M````%`,``!(`````````````````````````B0$``!(`````````````````
M````````AP```!(`````````````````````````0P,``!(`````````````
M````````````C@(``!(`````````````````````````/````"``````````
M````````````````Z````!(`````````````````````````9P$``!(`````
M````````````````````S`(``!(`````````````````````````.P(``!(`
M````````````````````````_0$``!(`````````````````````````J0(`
M`!(`````````````````````````4````"``````````````````````````
M'@,``"(`````````````````````````G`(``!(`````````````````````
M````+0,``!(`````````````````````````P0,``!(`#0`P5@```````'$`
M````````CP,``!(`#@!$5P``````````````````Y@,``!(`#0`P1@``````
M`$0,````````7@,``!(`#0"`'````````/<!````````E0,``!(`#0#`/@``
M``````4`````````5`0``!(`#0#0/@```````-8!````````3@0``!(`"@!@
M&@``````````````````@00``!(`#0"`4@```````*D#````````=`,``!``
M&``@L"``````````````````S0,``!(`#0"P0````````"0```````````0`
M`!$`#P!05P````````0`````````@`,``!``&`"HP"``````````````````
M3`0``!(`#0"`/0```````#``````````800``!(`#0"P1````````',!````
M````<P0``!(`#0``1````````'D`````````\P,``!``%P``L"``````````
M````````V@,``!(`#0#@0````````/$`````````8P,``!$`&`!(L"``````
M``@`````````;0,``!``%P`@L"``````````````````9`,``"$`&`!(L"``
M``````@`````````-00``!$`%P`8L"````````@`````````Z0(``!$`&`!@
ML"````````@`````````A0,``!(`#0!`5P````````(`````````)00``!(`
M#0#05@```````&4`````````^0,``!(`#0"`'@```````"H`````````]0,`
M`"``%P``L"``````````````````%0$``!$`&``@L"````````0`````````
M90,``"$`&`!(L"````````@`````````I@,``!(`#0"`1````````"0`````
M````#P0``!(`#0``/@```````+D`````````]P```!$`&`!`L"````````$`
M````````/P0``!(`#0#@00```````!("`````````&QI8G!E<FPN<V\N-2XR
M,@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?
M<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE
M=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L
M:6)P=&AR96%D+G-O+C``;W!E;C8T`')E860`7U]E<G)N;U]L;V-A=&EO;@!L
M<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;&EB8RYS;RXV`%]?
M<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F
M7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK
M`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H
M:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E
M;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN
M:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT
M;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET
M7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N
M-0!'3$E"0U\R+C$T`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N
M-````````@`#``(``@````(``@````(````"``(````"`````@`"``0``@`"
M`````````````P`"``4``@````(``P`"``(````&````!P````,``@``````
M```````````&```````"``,``@`"```````"``(``````````@`"``,`!@``
M``(``@`&``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``$`
M`@`!``(``0`!``$``0````(``0`!`````0```````0`!`-`!```0````(```
M`'4::0D```,`EP0````````!``4`'P(``!``````````E)&6!@``!P"C!```
M$````'09:0D```8`K@0``!````!R&6D)```%`+H$```0````%&EI#0``!`#&
M!```$````'4::0D```(`EP0```````#0JR````````@`````````@!\`````
M``#8JR````````@`````````0!\````````(L"````````@`````````"+`@
M```````8L"````````@`````````D%H```````#@K2````````8````"````
M``````````#HK2````````8````#``````````````#PK2````````8````$
M``````````````#XK2````````8````%````````````````KB````````8`
M```&```````````````(KB````````8````'```````````````0KB``````
M``8````(```````````````8KB````````8````)```````````````@KB``
M``````8````*```````````````HKB````````8````+```````````````P
MKB````````8````,```````````````XKB````````8````-````````````
M``!`KB````````8````.``````````````!(KB````````8````/````````
M``````!0KB````````8````0``````````````!8KB````````8````1````
M``````````!@KB````````8````2``````````````!HKB````````8````3
M``````````````!PKB````````8````4``````````````!XKB````````8`
M```5``````````````"`KB````````8````6``````````````"(KB``````
M``8````7``````````````"0KB````````8````8``````````````"8KB``
M``````8````9``````````````"@KB````````8````:``````````````"H
MKB````````8````;``````````````"PKB````````8````<````````````
M``"XKB````````8````=``````````````#`KB````````8````>````````
M``````#(KB````````8````?``````````````#0KB````````8````@````
M``````````#8KB````````8````A``````````````#@KB````````8````B
M``````````````#HKB````````8````C``````````````#PKB````````8`
M```D``````````````#XKB````````8````E````````````````KR``````
M``8````F```````````````(KR````````8````G```````````````0KR``
M``````8````H```````````````8KR````````8````I```````````````@
MKR````````8````J```````````````HKR````````8````K````````````
M```PKR````````8````L```````````````XKR````````8````M````````
M``````!`KR````````8````N``````````````!(KR````````8````O````
M``````````!0KR````````8````P``````````````!8KR````````8````Q
M``````````````!@KR````````8````R``````````````!HKR````````8`
M```S``````````````!PKR````````8````T``````````````!XKR``````
M``8````U``````````````"`KR````````8````V``````````````"(KR``
M``````8````W``````````````"0KR````````8````X``````````````"8
MKR````````8````Y``````````````"@KR````````8````Z````````````
M``"HKR````````8````[``````````````"PKR````````8````\````````
M``````"XKR````````8````]``````````````#`KR````````8````^````
M``````````#(KR````````8````_``````````````#0KR````````8```!`
M``````````````#8KR````````8```!!``````````````#@KR````````8`
M``!"``````````````#HKR````````8```!#``````````````#PKR``````
M``8```!$``````````````#XKR````````8```!%```````````````@L"``
M``````4```!@``````````````!`L"````````4```!D``````````````!(
ML"````````4```!7``````````````!@L"````````4```!;````````````
M``!(@^P(2(L%C90@`$B%P'0%Z",!``!(@\0(PP```````/\U2I,@`/\E3),@
M``\?0`#_)4J3(`!FD/\E2I,@`&:0_R5*DR``9I#_)4J3(`!FD/\E4I,@`&:0
M_R52DR``9I#_)5*3(`!FD/\E4I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@
M`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E
M6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!F
MD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3
M(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_
M)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``
M9I#_)5J3(`!FD/\E6I,@`&:0_R5BDR``9I#_)6*3(`!FD/\E8I,@`&:0_R5B
MDR``9I#_)6*3(`!FD/\E8I,@`&:0_R5BDR``9I#_)6*3(`!FD/\E8I,@`&:0
M_R5BDR``9I#_)6J3(`!FD/\E:I,@`&:0_R5RDR``9I#_)7*3(`!FD/\E<I,@
M`&:0_R5RDR``9I#_)7*3(`!FD/\E<I,@`&:0_R5ZDR``9I#_)7J3(`!FD/\E
M>I,@`&:055-(@^PXB7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`AD2(L$
M)2@```!(B40D*#'`Z/#^__](BS5YDB``2(L]RI(@`$B)\NCB.0``@#UKDR``
M`'4OZ%S^__](A<!(B06ZHR``#X1\`0``2(G'Z.S]__^+/2:3(`#HL?[__\:`
MQ0@```"+/123(`!(C1TW/```Z)C^__^`B,($```"BSW[DB``Z(;^__^`B,($
M```!BT0D'(UX!4AC_TC!YP/H'/[__TB+?"002(D%.*,@`+X%````QP4QHR``
M!````$B+%TB)6`A(C1W@.P``2(/'"$B)6!A(B1!(BQ69DB``2(E0$(M4)!R#
M^@&-2@1^%Y!,BP],8\:#Q@%(@\<(.<Y.B4S`^'7J2(L]\Z(@`$ACR4B--?D?
M``!(QT3(^`````"#P@-%,<!(B<'H(O[__X7`B<-T44B+/<6B(`!(C6PD).@[
M_?__2(T]!SH``#'`2(GNZ`H9``!(A<!T.DB+/9ZB(`#HZ?S__^C,_?__B=A(
MBUPD*&1(,QPE*````'542(/$.%M=PTB+/72B(`#H#_[__XG#ZY](BSU<HB``
M2(7_=`?HZC<``.NS2(T]63D``$B)[NBI&```2(7`2(G'2(D%-*(@`'25Z]F_
M`0```.C>_?__Z)'\__]F#Q^$```````Q[4F)T5Y(B>)(@^3P4%1,C06J.```
M2(T-,S@``$B-/=S]___HS_S___1F#Q]$``!(C3UID2``2(T%:9$@`%5(*?A(
MB>5(@_@.=A5(BP4NCR``2(7`=`E=_^!F#Q]$``!=PP\?0`!F+@\?A```````
M2(T]*9$@`$B--2*1(`!52"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!<&0
M(`!(A<!T#%W_X&8/'X0``````%W##Q]``&8N#Q^$``````"`/2&1(```=2=(
M@SV7D"```%5(B>5T#$B+/:J0(`#H!?W__^A(____7<8%^)`@``'SPP\?0`!F
M+@\?A```````2(T]68P@`$B#/P!U"^E>____9@\?1```2(L%"9`@`$B%P'3I
M54B)Y?_07>E`____05=!5DB-3SA!54%43(U7>%532('LF`(``&1(BP0E*```
M`$B)A"2(`@``,<!(B>9)B>!F#Q]$``"+$4B+`4B#P0A)@\`0#\J)TTB)PDC!
MZB!)B5CP28G12,'B"$G!X1B!X@``_P!%B<E,"<I)B<%(P>@H2<'I."4`_P``
M3`G*2`G028E`^$PYT76N2(U6:$B!QF@"```/'P!(BP)(,T+82(/""$@S0J!(
M,T*02(T,`$C!Z!]("<B#X/](B4(02#GR==9,BP](BU\@3(M7$$R+7QA(BV\(
M3(G*3(G(38G,2,'B!4C!Z!M,B=E("=!(B=I(`Q0DB<!)B>U(`TPD"$G!Y1Y)
MP>0>2(V4$)EY@EI,B=!,,=A((>A,,=A(`=!(B>I(P>H"08G'20G53(G23(G^
M18GM2,'F!4PQZDPARDPQTDB-C`J9>8):3(GZ2,'J&T@)\HG22(TT$4R)RDR)
M^4C!Z@)(]]%)"=1,(>E!B?!%B>1,(>!("<%,B=!(`T0D$$B-E`&9>8):3(G!
M3(G`2,'A!4C!Z!M("<B)P$B-#`),B?I,B?A(P>@"2,'B'D@)PDR)P$&)SHG2
M2/?03"'@2"'63`-L)!A("<9,B?!,`V0D($C!Z!M)C;0UF7F"6DV)]4G!Y05,
M">B)P$R-+`9,B<!)P>@"2,'@'DD)P$R)\$6)[T6)P$CWT$@AT$PAP4@#5"0H
M2`G!3(GX28VT#)EY@EI,B?E(P>@;2,'A!4@)R(G`2(T,!DR)\$G![@)(P>`>
M3(G^20G&2/?608G,1(GP3"'&22'%20GU3(GF3HVL*IEY@EI,B>)(P>X;2,'B
M!4@)\DR)_DG![P)(P>8>B=),`>I)"?=-B>5$B?Y)]]5!B=9)(<5((?%,">E,
M`T0D,$@#1"0X38VL")EY@EI-B?!,B?%)P>`%2,'I&TP)P8G)38U$#0!,B>%)
MP>P"2,'A'DD)S$6)Q42)X4V)]$GWU$@ARDDA]$@#="1`3`GB3(VD$)EY@EI,
MB>A,B>I(P>H;2,'@!4@)T$R)\DG![@)(P>(>B<!)"=9,`>!$B?)-B>Y!B<1)
M]]9)(=!)(<Y-"?!.C;0&F7F"6DR)YDV)X$G!Z!M(P>8%3`G&38GH2<'M`DG!
MX!Z)]DT)Q4P!]D6)Z$V)Y4&)]DGWU4PAP$DAU4P)Z$@#3"1(2`-4)%!,C:P!
MF7F"6DR)\4R)\$C!X05(P>@;2`G(B<!)C4P%`$R)X$G![`)(P>`>20G$08G-
M1(G@38GT2??42"'&32'$3`-$)%A,">9,C:0RF7F"6DR)ZDR)[DC![AM(P>(%
M2`GR3(GV2<'N`DC!YAZ)TDD)]DP!XD2)]DV)[D&)U$GWUD@A\4DAQDP)\4V-
MM`B9>8):38G@3(GA2<'@!4C!Z1M,"<&)R4V-!`Y,B>E)P>T"2,'A'DD)S46)
MQD2)Z4V)Y4GWU4@ARDDA]4P)ZD@#1"1@2`-T)&A,C:P0F7F"6DR)\$R)\DC!
MZAM(P>`%2`G03(GB2<'L`DC!XAZ)P$D)U$P!Z$2)XDV)]$&)Q4GWU$DAT$DA
MS$@#3"1P30G@3HVD!IEY@EI,B>Y-B>A)P>@;2,'F!4P)QDV)\$G![@))P>`>
MB?9-"<9,`>9%B?!-B>Y!B?1)]]9,(<!)(=9,"?!,C;0!F7F"6DR)X4R)X$C!
MX05(P>@;2`G(B<!)C0P&3(GH2<'M`DC!X!Y)"<5!B<Y$B>A-B>5)]]5((<9-
M(<5,">Y(`U0D>$P#A"2`````3(VL,IEY@EI,B?),B?9(P>X;2,'B!4@)\DR)
MYDG![`)(P>8>B=))"?1,`>I$B>9-B?1!B=5)]]1((?%)(<1(`X0DB````$P)
MX4V)[$V-A`B9>8):3(GI2<'D!4C!Z1M,">&)R4V-)`A,B?%)P>X"2,'A'DD)
MSD6)X$2)\4V)[DGWUD@ARDDA]D@#M"20````3`GR38G&2(V4$)EY@EI,B<!)
MP>8%2,'H&TP)\(G`3(TT`DR)ZDG![0)(P>(>20G51(GP1(GJ38G%28G'2??5
M22'422'-30GL2<'G!4V)Q4Z-I":9>8):2(G&2<'H`DC![AM)P>4>2`.,))@`
M``!,"?Y-"<6)]D6)Z$V-/#1(B<9-(<9(]]9,`X0DJ````$@AUD6)_$@#E"2@
M````20GV3(GF3HVT,9EY@EI,B>%(P>8%2,'I&T@)\8G)28TT#DB)P4C!Z`)(
MP>$>2`G(08GV23'%13'O38GU2HV,.J'KV6Y,B?))P>4%2,'J&TP)ZHG23(TL
M$4R)X4G![`)(P>$>2(G"B<!,">%%B>]-B?1(,<I)P>0>,=9,B?I)C;0PH>O9
M;DV)^$C!ZAM)P>`%3`G"2<'N`D@#A"2P````B=)-"?1,C0062(G*B<E,,>)(
M`XPDN````$2)QD$QU4Z-K"BAZ]EN2(GR2(GP2,'J&TC!X`5("=!,B?I)P>\"
M2,'B'HG`3`GZ3`'H38GE23'508G&13'H3HVL`:'KV6Y,B?%-B?!)P>@;2,'A
M!4P)P4F)\$C![@))P>`>B<E)"?!$B>9(`[0DP````$F)U$P!Z8G233'$08G/
M1#'@3(VD!J'KV6Y,B?A,B?Y(P>X;2,'@!4@)\$R)]DG![@)(P>8>B<!,"?9,
M`>!(`Y0DR````$V)Q$&)Q46)P$DQ]$P#A"30````1#'A3(VD"J'KV6Y,B>I,
MB>E(P>D;2,'B!4@)RDR)^4G![P)(P>$>B=),"?E,`>))B?1),<Q!B=:)]D0Q
MX$@#M"38````38VD`*'KV6Y-B?!,B?!)P>`%2,'H&TP)P(G`38T$!$R)Z$G!
M[0)(P>`>3`GH28G-18G$23'%B<E(`XPDX````$0QZDR-K!:AZ]EN3(GF3(GB
M2,'F!4C!ZAM("?*)TDF-=!4`3(GR2<'N`DC!XAY,"?))B<9!B?5),=:)P$4Q
M\$Z-M`&AZ]EN3(GI38GH2,'A!4G!Z!M(`X0DZ````$P)P4V)X$G![`))P>`>
MB<E-">!)B=1,`?%-,<1!B<Z)TD0QYD@#E"3P````3(VD,*'KV6Y,B?!,B?9(
MP>X;2,'@!4@)\$R)[DG![0)(P>8>B<!,">Y-B<5,`>!),?5!B<1%B<!$,>E,
M`X0D^````$R-K`JAZ]EN3(GB3(GA2,'I&TC!X@5("<I,B?%)P>X"2,'A'HG2
M3`GQ28GV3`'J23'.08G5B?9$,?!-C;0`H>O9;DV)Z$R)Z$G!X`5(P>@;3`G`
MB<!-C00&3(G@2,'@'D@#M"0``0``2<'L`DP)X$F)S$6)QDDQQ(G)2`.,)`@!
M``!$,>),C:06H>O9;DR)]DR)\DC!Y@5(P>H;2`GRB=))C3043(GJ2<'M`DC!
MXAY,">I)B<5!B?1),=6)P$@#A"00`0``13'H3HVL`:'KV6Y,B>%-B>!)P>@;
M2,'A!4P)P4V)\$G![@))P>`>B<E-"?!)B=9,`>E-,<9!B<V)TD0Q]DR-M#"A
MZ]EN3(GH3(GN2,'N&TC!X`5("?!,B>9)P>P"2,'F'HG`3`GF3`'P2`.4)!@!
M``!-B<1!B<9%B<!),?1,`X0D(`$``$0QX4R-I`JAZ]EN3(GR3(GQ2,'I&TC!
MX@5("<I,B>E)P>T"2,'A'HG23`GI28GU3`'B23'-08G4B?9$,>A(`[0D*`$`
M`$V-K`"AZ]EN38G@3(G@2<'@!4C!Z!M,"<")P$V-1`4`3(GP2<'N`DC!X!Y,
M"?!)B<Y%B<5),<:)R4@#C"0P`0``1#'R3(VT%J'KV6Y,B>Y,B>I(P>8%2,'J
M&T@)\HG228TT%DR)XDG![`)(P>(>3`GB28G$08GV23'4B<!%,>!-B?1.C80!
MH>O9;DR)\4G!Y`5(P>D;2`.$)#@!``!,">&)R4V-)`A-B>A)P>T"2<'@'DT)
MZ$F)U42)X4TQQ8G21#'N28G-2(VT,*'KV6Y(B<A)P>4%2,'H&TP)Z(G`3(TL
M!DR)]DG![@)(P>8>3(G`3`GV18GO2`GP22'$3(G`18G`2"'P00G$N-R\&X])
MB<9,`[0D0`$``$P!\DV)_DP!XDV)_$G!Y@5)P>P;30GT18GD20'42(G*2,'I
M`DC!XAY%B>9("=%(B?)("<I)(=5(B?*)]D@ARD$)U4B)PD@#E"1(`0``3`'"
M38GP3`'J38GU2<'H&TG!Y05-">A%B<!)`=!,B?I)P>\"2,'B'D6)Q4P)^DF)
MSTD)UTTA_$F)SXG)22'710G\28G'3`.\)%`!``!,`?Y-B>],`>9-B>Q)P><%
M2<'L&TT)_$6)Y$P!YDV)]$G![@))P>0>08GW30GT28G630GF32'P28G6B=)-
M(>9%"?!)B<9,`[0D6`$``$P!\4V)_DP!P4V)^$G!Y@5)P>@;30GP18G`3`'!
M38GH2<'M`DG!X!Y!B<Y-">A-B>5-"<5,(>Y-B>5%B>1-(<5$">Y)B<5,`ZPD
M8`$``$P!ZDV)]4@!\DR)]DG!Y05(P>X;20GU3(G^2<'O`DC!YAY%B>U,"?Y-
MB<=)`=5)"?=$B>I,(?E-B<=%B<!)(?=$"?E)B<=,`[PD:`$``$T!_$F)UTP!
MX4F)U$G!YP5)P>P;30GG18G_20'/3(GQ2,'A'DG![@)%B?Q,"?%)B?9)"<Y-
M(?5)B?:)]DDASD4)]4F)QDP#M"1P`0``30'P38GF30'H38GE2<'F!4G![1M-
M">Y%B?9-`<9)B=!(P>H"2<'@'D6)]4P)PDF)R$D)T$TAQTF)R(G)22'010G'
M28G`3`.$)'@!``!,`<9-B>A,`?Y-B>])P>@;2<'G!4T)^$6)P$D!\$R)YDG!
M[`)(P>8>18G'20GT2(G63`GF22'V2(G6B=),(>9!"?9(B<9(`[0D@`$``$@!
M\4R)_DP!\4V)_DC![AM)P>8%20GV3(GN2<'M`DC!YAY%B?9,">Y-B>5)`<Y)
M"?5$B?%-(>A-B>5%B>1)(?5%">A)B<5,`ZPDB`$``$P!ZDF)S4P!PDF)R$G!
MY05)P>@;30G%38GX2<'O`DG!X!Y%B>U-"?A)B?=)`=5-"<=$B>I-(?Y)B?>)
M]DTAQT4)_DF)QTP#O"20`0``30'\28G730'T28G62<'G!4G![AM-"?Y%B?9-
M`>9)B<Q(P>D"2<'D'D6)]TP)X4V)Q$D)S$TAY4V)Q$6)P$DAS$4)Y4F)Q$P#
MI"28`0``3`'F38G\3`'N38G]2<'L&TG!Y05-">Q%B>1)`?1(B=9(P>H"2,'F
M'D6)Y4@)\DB)SD@)UDDA]DB)SHG)2"'600GV2(G&2`.T)*`!``!,`<9-B>A,
M`?9-B>Y)P>@;2<'F!4T)\$6)P$D!\$R)_DG![P)(P>8>18G&3`G^28G720GW
M32'\28G7B=))(?=%"?Q)B<=,`[PDJ`$``$P!^4V)]TP!X4V)]$G!YP5)P>P;
M30G\18GD3`'A38GL2<'M`DG!Y!Y!B<]-">Q)B?5-">5-(>A)B?6)]DTAY44)
MZ$F)Q4P#K"2P`0``3`'J38G]3`'"38GX2<'E!4G!Z!M-"<5-B?!)P>X"2<'@
M'D6)[4T)\$V)YDD!U4T)QD2)ZDPA\4V)YD6)Y$TAQD0)\4F)QDP#M"2X`0``
M3`'V28G62`'Q2(G62<'F!4C![AM)"?9%B?9)`<Y,B?E)P>\"2,'A'D2)]DP)
M^4V)QTD)STTA_4V)QT6)P$DAST4)_4F)QTP#O"3``0``30'\28GW30'L28GU
M2<'G!4G![1M-"?U%B>U-`>5)B=1(P>H"2<'D'D6)[TP)XDF)S$D)U$TAYDF)
MS(G)22'410GF28G$3`.D),@!``!-`>!-B?Q-`?!-B?Y)P>P;2<'F!4T)YD6)
M]DT!QDF)\$C![@))P>`>18GT3`G&28G020GP32'%28G0B=))(?!%"<5)B<!,
M`X0DT`$``$@#A"38`0``3`'!38G@3`'I38GE2<'H&TG!Y05(`=!-"<5%B>U)
M`<U,B?E)P>\"2,'A'D6)Z$P)^4F)]TR)PDD)STTA_DF)]XGV22'/10G^3`'P
M38G&2<'F!4C!ZAM)"=9%B?9)`<9,B>!)P>P"2,'@'D2)\DD)Q+C6P6+*28G'
M3`.\).`!``!,`?Y)B<^)R4TQYT4Q_4F)UTP![DF)U4G!YP5)P>T;30G]38G'
M2<'H`DG!YQY%B>U-"?A)B<=,`[PDZ`$``$D!]42)[DP!^4V)YT6)Y$TQQT4Q
M_DF)]TP!\4F)]DG!YP5)P>X;30G^28G72,'J`DG!YQY%B?9)"==(B<)(`Y0D
M\`$``$D!SD2)\4P!XDV)Q$6)P$TQ_$4QY4F)S$P!ZDF)S4G![!M)P>4%30GL
M28GU2,'N`DG!Y1Y%B>1,">Y)B<5,`ZPD^`$``$D!U$2)XDT!Z$V)_46)_TDQ
M]44Q[DF)U4T!\$F)UDG![1M)P>8%30GU28G.2,'I`DG!YAY%B>U)"<Y(B<%(
M`XPD``(``$T!Q46)Z$P!^4F)]XGV33'W13'\38G'3`'A38G$2<'G!4G![!M-
M">=)B=1%B?])P>0>20'/2,'J`DD)U$B)PD@#E"0(`@``1(GY2`'R3(GV18GV
M3#'F03'U2(G.3`'J28G-2,'N&TG!Y05)"?5%B>U)`=5,B<))P>@"2,'B'D2)
M[DD)T$B)PD@#E"00`@``3`'R38GF18GD33'&13'W28GV3`'Z28GW2<'N&TG!
MYP5-"?=)B<Y(P>D"2<'F'D6)_TD)SDB)P4@#C"08`@``20'71(GZ3`'A38G$
M18G`33'T13'E28G43`'I28G52<'E!4G![!M-">5%B>U)`<U(B?%(P>X"2,'A
M'D6)[$@)SDB)P4@#C"0@`@``3`'!38GP18GV23'P13''38G@3`'Y38GG2<'H
M&TG!YP5-"<=)B=!(P>H"2<'@'D6)_TD)T$B)PD@#E"0H`@``20'/1(GY3`'R
M28GVB?9-,<9%,?5)B<Y,`>I)B<U)P>8%2<'M&TT)[D6)]DD!UDR)XDG![`)(
MP>(>18GU20G42(G"2`.4)#`"``!(`?),B<9%B<!,,>9!,?=,B>Y,`?I-B>](
MP>X;2<'G!4D)]TB)SDC!Z0)(P>8>18G_2`G.2(G!2`.,)#@"``!)`==$B?I,
M`<%-B>!%B>1),?!%,<9)B=!,`?%)B=9)P>@;2<'F!4T)QD6)]DD!SDR)Z4G!
M[0)(P>$>18GP20G-2(G!2`.,)$`"``!,`>%)B?2)]DTQ[$4QYTV)Q$P!^4V)
MQTG![!M)P><%30GG28G418G_2<'D'DD!STC!Z@))"=1(B<)(`Y0D2`(``$2)
M^4@!\DR)[D6)[4PQYD$Q]DB)SDP!\DF)SDC![AM)P>8%20GV18GV20'63(G"
M2<'H`DC!XAY$B?9)"=!(B<)(`Y0D4`(``$P!ZDV)Y46)Y$TQQ44Q[TF)]4P!
M^DF)]TG![1M)P><%30G]28G/2,'I`DG!YQY%B>U,"?E)B<=,`[PD6`(``$D!
MU42)ZDT!_$V)QT6)P$DQST4Q_DF)UTT!]$F)UDG!YP5)P>X;30G^28GW2,'N
M`DG!YQY%B?9,"?Y)B<=,`[PD8`(``$T!]$6)YDT!^$F)SXG)23'W13']38GW
M30'H38GU2<'G!4G![1M-"?U)B==(P>H"2<'G'D6)[4P)^DF)QTP#O"1H`@``
M30'H18G%3`'Y28GWB?9),==%,?Q-B>],`>%-B>Q)P><%2<'L&TT)_$V)]TG!
M[@))P><>18GD30G^28G'3`.\)'`"``!,`>%!B<Q,`?Y)B=>)TDTQ]T@#A"1X
M`@``1`'S13'X38GG2(E?($P!QDV)X$G!YP5)P>@;30GX2`'03(GR1`'&38GH
M2<'M`DG!X!Y-"<5-B>!)P>P"3#'J2<'@'D4!ZS'12(GR30G$2`'(2(GQ2,'J
M&TC!X04![D4!XD@)RDB)=PA,B5<0`=!,B5\800'!2(N$)(@"``!D2#,$)2@`
M``!,B0]U$DB!Q)@"``!;74%<05U!7D%?P^@2Y/__9BX/'X0``````$B%_P^$
MO@```$%7059!54%455-(@^P(3(L]*GD@`$V%_W1C#[8'A,!T=CP]='))B?Q)
M@\0!00^V!"2$P'0$/#UU[T$I_$F+'TB%VW0Y28GU28G^36/D3(G]#Q^`````
M`$R)XDR)]DB)W^@ZX___A<!U!T*`/",]="](@\4(2(M=`$B%VW7:2(/$"#'`
M6UU!7$%=05Y!7\-F#Q^$``````!%,>3KH`\?`$PI_4J-1",!2,']`T&);0!(
M@\0(6UU!7$%=05Y!7\,QP,-F#Q]$``!54TB)_4B#[!AD2(L$)2@```!(B40D
M"#'`2(U<)`1FD#'`2(G>2(GOZ`/___](A<!T,$AC5"0$2(L%.G@@`$B-!-!(
MBU`(2(722(D0=-)FD$B#P`A(BU`(2(722(D0=?#KODB+1"0(9$@S!"4H````
M=0=(@\086UW#Z+KB__]FD$%7059!54%455-(B?-(B?U(@^PH9$B+!"4H````
M2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z'GB__](C70D%$F)Q$B)[S'`Z&?^__](
MA<`/A`X!``!(B<=)B<7H4^+__TDYQ`^&X@```$QC="042<'F`P^V10"$P`^$
MJP$``#P]#X2C`0``2(GHZPT/'X0``````(#Z/70+2(/``0^V$(32=?!(*>A(
MF$P#-4QW(`!*C7P@`NBRXO__2(7`28D&#X1X`0``2&-4)!1(BP4J=R``2(U-
M`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]=!)(@\$!#[9!_TB#
MP@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`2(MT)!AD2#,T
M)2@````/A0X!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#_TF#Q0&$P$&(
M1?]U[.O"9I!,BSV1=B``28,_``^$O````$R)^#'2ZPL/'X0``````$2)ZDB#
MP`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%CX8@`(7`=#M,B?_H`^+__TB%P$B)
M!4%V(``/A'T```!-8\5(B<%.C33%`````$K'1,$(`````$2);"04Z9'^__]F
MD$B)]\<%0X8@``$```#H=N'__TB%P'1#36/%3(G^2(G'3HTTQ0````!,B40D
M"$R)\NBKX?__3(M$)`A(B<%(B074=2``ZZ4QP.EX_O__OA````!%,>WI8?__
M_[C_____Z=[^___H;^#__P\?@`````!!5D%505154TB![*````!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@S!"4H````#X4I
M`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HT]___TB%P$F)Q'3"28GE
M3(GGZ`#A__](A<!(B<,/A*0```"`>Q,N#X2R````2(/#$TB)[^C&W___2(G?
M28G&Z+O?__]!C7P&`DAC_^AFX/__2(T-^QL``$F)QDB)QTF)V4F)Z$C'PO__
M__^^`0```#'`Z`#A__^_`0```$R)ZDR)]NA(W___@_C_3(GW=!"+1"08)0#P
M```]`$```'1HZ/O>__],B??HX][__TR)Y^ACX/__2(7`2(G##X5C____#Q^`
M`````$R)Y^AXW___2(GOZ"#?___I\O[__P\?``^V0Q2$P`^$)/___SPN#X4Z
M____@'L5``^$$O___^DK____#Q]$``#HD_[__^N6Z/3>__]FD&8N#Q^$````
M``!32(G[BSWV<R``Z('?__](C9#X`0``2(G>OP$```#H!>#__X7`=`DQP%O#
M#Q]$``"+/<IS(`#H5=___XN`$`(``"4`\```/0!```!T'8L]K7,@`.@XW___
MBX`0`@``)0#P```]`*```'6]2(G?O@(```#HD=___X7`#Y3`#[;`6\,/'T0`
M`&8N#Q^$``````!!54%428G\55-(C3V:&@``28GUNO\/``!(@>P8$```2(GF
M9$B+!"4H````2(F$)`@0```QP.C.W?__A<!^<HU0_TB)XTACZH`\+`!T6TAC
MZ$B)ZKXO````2(G?Z%C>__](A<!T2XL]!7,@`.B0WO__2(GI2(G:3(GF2(G'
MZ`??__](BX0D"!```&1(,P0E*````'4W2('$&!```%M=05Q!7<-F#Q]$``"%
MTG6D#Q]``(L]NG(@`.A%WO__3(GJ3(GF2(G'Z*_=___KMNB(W?__2(/L"(L]
MEG(@`.@AWO__2(L5DG`@`$B-#=L;``!(C37%&0``2(G'2(/$".D@WO__2(/L
M"(L]9G(@`.CQW?__2(G'Z+G___^+/5-R(`#HWMW__TR-!5`;``!(C16@%```
M2(TUGAD``$4QR4B)QTB#Q`A,B<'I_]W__P\?@`````!54TB!["@@``!D2(L$
M)2@```!(B80D&"```#'`Z*?<__],C0T]&0``2(T-:QD``$&)P+H!$```,<"^
M`0```$B)Y^@RWO__A<!X9DB-K"00$```N@`0``!(B>=(B>[H5MS__X7`2(G#
M>$>->`%(8__H1-W__TB%P'0W2&/;2(GN2(G'2(G:Z!;=___&!!@`2(N4)!@@
M``!D2#,4)2@```!U$TB!Q"@@``!;7<,/'T0``#'`Z]KH3]S__P\?@`````#I
M.____Y!F+@\?A```````05=!5D%5051)B?154TB)^TB-/<$8``!(@>PH$```
M9$B+!"4H````2(F$)!@0```QP$B-="0,Z/7W__^^+P```$B)WTB)Q>C]V___
M2(7`=#U(C3V*&```2(G>,<#H'_G__TB)V$B+C"08$```9$@S#"4H````#X56
M`0``2('$*!```%M=05Q!74%>05_#2(G?3(TM/Q@``.B4V___2(TU2Q@``$&)
MQDR)YTR-9"0008/&`>BIW/__28G'9@\?1```387_=(M!@#\`30]$_4B%[703
M3(G^2(GOZ-/;__^%P`^$J0```$R)_^A#V___B<)(F$&`?`?_+W4:#Q^`````
M`(/J`4ACPD&`?`?_+T'&!`<`=.U$`?*!^O\/```/CR[___](@^P(2(T-XA@`
M`$R-#;P7``!338GXN@`0``"^`0```$R)YS'`Z%S<__^+/?YO(`#HB=O__TB-
MD/@!``!,B>:_`0```.B5VO__A<!:674=BSW9;R``Z&3;__^+@!`"```E`/``
M`#T`@```=!9(C359%P``,?_HQ-O__TF)Q^D<____O@$```!,B>?HI]O__X7`
M==E(C3TE%P``3(GFZ+SW__],B>?HO-K__^F3_O__Z&+:__]F+@\?A```````
M#[8/2(GXA,ET&$B-5P%FD(#Y+P^V"D@/1,)(@\(!A,EU[O/#9I!F+@\?A```
M````55-(@^P(2(7_=#4/MB](B?M`A.UT*N@%VO__2(U4`_](.=-R%.M/9@\?
MA```````2(/J`4@YTW1'@#HO=/+K+;\"````Z([:__](A<`/A)4```"Z+@``
M`&:)$$B#Q`A;7<-F#Q]$``"`.B]T.$B#Z@%(.=-R\D@YTW4J#Q]$``!`@/TO
M=+I(@\0(2(T]3Q8``%M=Z>#9__\/'X0``````(`Z+W4)2(/J`4@YTW+R2"G:
M2(U"`D@]`!```'<K2(T]W&X@`$B)WDB#P@&Y`!```.@SVO__2(/$"$B-!<!N
M(`!;7<,/'T0``$B#Q`@QP%M=PP\?1```9BX/'X0``````%-(C3W:%0``2(/L
M0&1(BP0E*````$B)1"0X,<!(BP5-%P``2(U<)`Q(B40D$$B+!407``!(B40D
M&$B+!4`7``!(B40D($B+!3P7``!(B40D*`^W!3@7``!FB40D,#'`Z(SU__](
MC3V`%0``,<#H?O7__TB-/7H5```QP.AP]?__2(T]=14``#'`Z&+U__](C3UN
M%0``,<#H5/7__TB-/7`5```QP.A&]?__2(T]%Q4``#'`Z#CU__](C3U@%0``
M,<#H*O7__TB-/5P5```QP.@<]?__2(T]6!4``#'`Z`[U__](C3WH%```,<#H
M`/7__TB-/485```QP.CR]/__2(T]014``#'`Z.3T__](C3T^%0``,<!(B=[H
M`_3__TB%P'012(T]`!4``$B)QC'`Z#WU__](C3TH%0``,<!(B=[HW//__TB%
MP'012(T])!4``$B)QC'`Z!;U__](C3T>%0``,<!(B=[HM?/__TB%P'1`2(T]
M410``$B)QC'`Z._T__](C34C%0``2(T]=!0``#'`Z-KT__](BT0D.&1(,P0E
M*````'5G2(/$0%O##Q]``$B-/=@4```QP$B)WNA?\___2(7`=!I(C3U2%```
M2(G&,<#HF?3__^NH#Q^``````$B-="0A2(T]M!0``+D*````\Z9UC$B-="0K
M2(T]'A0``#'`Z&CT___I=/___^@6U___#Q]``&8N#Q^$``````!(@^P89$B+
M!"4H````2(E$)`@QP(L%]FL@`(/X_W092(M,)`AD2#,,)2@```!U14B#Q!C#
M#Q]``$B-="0$2(T]NQ,``#'`Z+7R__](A<!T(`^V$(#Z,`^5P(32#Y7"#[;2
M(=")!:=K(`#KM`\?1```,<#K[^B/UO__#Q^``````$B#[`CHA];__XG'Z%C6
M__](A<!T"TB+`$B#Q`C##Q\`,<#K]&:09BX/'X0``````$%7059)B?Y!54%4
M3(TMU1,``%533(TEPA,``$B#[&AD2(L$)2@```!(B40D6#'`2(T%L1,``$C'
M1"10`````$B-;"0@3(U\)!Q(B40D($B-!8@3``!(B40D*$B-!8D3``!(B40D
M,$B-!7,3``!(B40D.$B-!6P3``!(B40D0$B-!7(3``!(B40D2.LA#Q]``$B)
MQ^@HU___2(7`=&-(@\4(387D=#=-B>5,BV4(3(G^,<!,B>_HEO'__TB%P$B)
MPTR)]G0%@#@`=<8QP$R)[TB#Q0CHR/+__TV%Y'7)2(M$)%AD2#,$)2@````/
MA7T```!(@\1H6UU!7$%=05Y!7\-,B??H2-7__TB)WTB)1"0(Z#O5__](BU0D
M"$B-?`("Z.35__](@^P(3(T-WQ$``$B-#?D2``!32,?"_____TB)QTV)\+X!
M````2(E$)!@QP.ASUO__3(M4)!A,B>\QP$R)UN@Y\O__6%KI+____^CEU/__
M#Q\`9BX/'X0``````$%7059!54%428G]55-(C3UD$0``2('LB($``&1(BP0E
M*````$B)A"1X@0``,<!(C059$@``2(UL)"Q(QT0D0`````!(QX0DF```````
M``!(QT0D8`````!(B40D,$B-!1(1``!(B>Y(B40D.$B-!;$1``!(B40D<$B-
M!9X1``!(B40D>$B-!0@2``!(B80D@````$B-!:`1``!(B80DB````$B-!?(1
M``!(B80DD````$B-!<H1``!(B40D4$B-!=L1``!(B40D6#'`Z`#P__](A<!T
M"8`X``^%8@0``#'`Z&O]__](A<!(B<,/A&P$``!(B=_HU]/__TB-?``!Z(74
M__^`.P!)B<9)B<1T,&:01`^V`TB-#8T1``!,B><QP$C'PO____^^`0```$B#
MPP%)@\0"Z`_5__^`.P!UTDR-9"1P2(T]VA```.L1#Q]``$F#Q`A)BSPD2(7_
M=#,QP$B)[NAI[___2(7`2(G#=.&`.`!TW$B)Q^AT]/__A<!TT$B)W^B@T___
M2(7`2(G#=5I(BUPD,$B%VP^$:@$``(`[`$&\`0```'4EZ5H!``!FD$ECQ$B+
M7,0P2(7;#X1'`0``08/$`8`[``^$.@$``$B)W^@:]/__A<!TUDB)W^A&T___
M2(7`2(G#=,9(B=_HWM+__TR)\8LQ2(/!!(V6__[^_O?6(?*!XH"`@(!TZ(G6
MP>X0]\*`@```#T362(UQ`D@/1,Z)UD``UDB#V0-,*?%$C;P(!`0``$UC_TR)
M_^A&T___28G$2(T%:A```$%63(T-.P\``$B-#5$0``!)B=A02,?"_____[X!
M````3(GG,<#HTM/__[[``0``3(GGZ/W1__^#^/]!6$%9#X2`````BSU:9R``
MZ.72__](C9#X`0``3(GFOP$```#H:=/__X7`#X29````28M-`$B+/6YG(`!(
MC17/$```38G@O@$````QP.A8T___,<!(BXPD>($``&1(,PPE*`````^%3@D`
M`$B!Q(B!``!;74%<05U!7D%?PP\?1```,=OIV_[__Y#H4]'__T2+"$&#^1$/
MA&[___])BTT`2(L]`V<@`$B-%200``!-B>"^`0```#'`Z.W2__\QP.N39@\?
MA```````BSV:9B``Z"72__^+@!`"```E`/```#T`0```#X5&____BSUY9B``
MZ`32__^+F!0"``#H6='__SG##X4H____BSU;9B``Z.;1__^+@!`"```E_P$`
M`#W``0``#X4'____3(G_Z-#1__](C3VA#@``2(G#2(GN,<#H!.W__TB%P`^$
MZP$``$B)Q^A+T?__28M]`$B)QNBW]/__2(7`2(G%#X3+`0``2(GOZ-/0__^#
M^`-^-DACT$B-/:\.``"Y!0```$B-=!7\\Z9U'H/X!`^$Q`8``(/H!$B8@'P%
M_R\/A+0&```/'T0``#'`Z)'Y__^%P'45,?9(B>_HB]'__X7`B00D#X5Q`0``
M2(TU_`T``$B-/6D-```QP#'MZ+'M___H)-#__TB-#7X.``!,C0T.#0``2,?"
M_____TV)X+X!````2(G?44B-#3@.``!0,<#HI-'__UA:ZU,/'X0``````.BS
MS___@S@1=5/HV<___TB-#3,.``!(@^P(@\4!3(T-O`P``$V)X$C'PO____]1
M2(T-_`T``%50O@$```!(B=\QP.A1T?__2(/$(+[``0``2(G?Z'C/__^#^/]T
MHTR)Y^A+S___2(T]7`P``$B)WC'`Z/KL__](B=_H4OG__TB)V.FD_?__9BX/
M'X0``````$B)QTB)!"3H-/G__TB+!"1(B<?HT,___^E]_?__2(T]'@T``$&\
M`0```.L5#Q]``$ECQ$&#Q`%(BWS$4$B%_W0I,<!(B>[H1>O__TB%P'3@@#@`
M=-M(B<?HB\___TB%P$B)PW3+Z4?[__^_#0```$B-'=$,``#I0_O__P\?1```
M28MM`.DL_O__3(VT)'`!``"Z`@```$C'QN[___]!B<>)Q^A!T/__N@8```!,
MB?9$B?_H2<___X"\)'`!````=0Z`O"1Q`0``0P^$H04``(L\)#'2,?9,C:PD
MH````.@%T/__N(FKS>](QX0DH`````$C16=(QX0DN````'94,A!(B80DJ```
M`+C^W+J82,>$),@`````````2(F$)+````"X\.'2PTC'A"30`````````$B)
MA"3`````28U%.,>$)!@!````````2(E$)!!FD(L\)+H`@```3(GVZ*#.__^%
MP$B)Q4&)P`^.LP$``$B+E"3(````2&/%C33"2#GR#X>+`0``2(N4)-````!(
MP>@=2(FT),@```!(`=!(B80DT````$ACA"08`0``A<`/A$P!``!!N$````!(
MBW0D$$$IP$0YQ40/3L5(C3P&3(GV26/(2(G*28G/2(E,)`CH3<[__XN$)!@!
M``!$`?B#^$")A"08`0``#X53____08GH3(GO12GX3(M\)`A$B40D'.@KTO__
M1(M$)!Q-`?</'P!!@_@_#XZX`P``08U`P(E$)!S!Z`:)Q8E$)`A(@\4!2,'E
M!DP!_68N#Q^$``````!)BQ=,B>])@\=`2(F4)-@```!)BU?(2(F4).````!)
MBU?02(F4).@```!)BU?82(F4)/````!)BU?@2(F4)/@```!)BU?H2(F4)``!
M``!)BU?P2(F4)`@!``!)BU?X2(F4)!`!``#HA='__TPY_760BT0D"$2+1"0<
MP>`&02G`2(M\)!!)8]"Y2````$B)[D2)1"0(Z#?-__]$BT0D"$2)A"08`0``
MZ57^__\/'T0``$V)]^D8____#Q^$``````!(BXPDT````$B-40'I;/[__XL\
M).BGS/__2(NL),@```!,B[0DT````$B)Z$C!Z`.#X#^-4`%(F,:$!-@```"`
M@_HX#X^1`@``N#@````IT$ACTHG!28U$%3B#^0@/@[<"``#VP00/A60#``"%
MR70,]L$"Q@``#X5G`P``3(GP3(GO1(BT)!,!``!(P>@80(BL)!<!``!,C;PD
M0`$``(B$)!`!``!,B?!,C:PD(0$``$C!Z!"(A"01`0``3(GP38UW*$C!Z`B(
MA"02`0``2(GH2,'H&(B$)!0!``!(B>A(P>@0B(0D%0$``$B)Z$R)_4C!Z`B(
MA"06`0``Z#'0__](BX0DH````$B)PHB$)",!``!(P>H81`^VPHB4)"`!``!(
MB<)(P>H0B)0D(0$``$B)PDB+A"2H````2,'J"(B4)"(!``!(B<*(A"0G`0``
M2,'J&(B4)"0!``!(B<)(P>H0B)0D)0$``$B)PDB+A"2P````2,'J"(B4)"8!
M``!(B<*(A"0K`0``2,'J&(B4)"@!``!(B<)(P>H0B)0D*0$``$B)PDB+A"2X
M````2,'J"(B4)"H!``!(B<*(A"0O`0``2,'J&(B4)"P!``!(B<)(P>H0B)0D
M+0$``$B)PDB+A"3`````2,'J"(B4)"X!``!(B<*(A"0S`0``2,'J&(B4)#`!
M``!(B<)(P>H0B)0D,0$``$B)PDC!Z@B(E"0R`0``Z0P````/'P!%#[9%`$F#
MQ0%(C0T@"```2(GO,<!(Q\+_____O@$```!(@\4"Z*;+__],.?5UT4B-!4L(
M``#&A"1H`0```%!!5TB-#04(``!,C0W)!@``O@$```!-B>!(Q\+_____2(G?
M,<#H:,O__UE>Z2;Z__]-BVT(387M#X1$^?__3(GOZ-3)__](@_@##X8R^?__
M28UT!?Q(C3VN!P``N04```#SIDD/1.WI%OG__TR)_>GE_/__N$````!(8\HI
MT$F-3`TXB<)T#S'`B<:#P`$YT,8$,0!R\TR)[^@LSO__28U5.+D'````,<!(
MB=?S2*OI8OW__XG*2,<``````$C'1!#X`````$B-4`A(@^+X2"G0`<B#X/B#
M^`@/@C?]__^#X/@QR8G.@\$(.<%(QP0R`````'+OZ1S]__^`O"1R`0``00^%
M4?K__X"\)',!``!##X5#^O__@+PD=`$``$@/A37Z__^`O"1U`0``10^%)_K_
M_T2+/"2Z`@```$C'QL;___]$B?_H*,K__[HI````3(GV1(G_Z##)__](C07B
M!@``4$%6Z9K^__^0QP``````QT0(_`````#IF?S__S'_9HE\"/[IC?S__^B4
MR/__9I!F+@\?A```````059!54%455-(@^P0BSV.72``3(UL)`1D2(L$)2@`
M``!(B40D"#'`Z`3)__](C3TP!0``QH"Q`````4R)[C'`Z#SD__](A<!T"8`X
M,0^$K@(``#'`Z`?O__^+/4%=(`#HS,C__TB--3@&``"Y"P```+H!````2(G'
MZ(O(__](A<`/A+L```"#/8-M(``!2(M`$$R+8"@/CJ8````Q[;L!````ZR\/
M'T``28MV$$B+!55M(`!(8]-(BSS0Z$'(__^%P'5MBP5';2``@\,!@\4!.=A^
M8XL]QUP@`.A2R/__,<E(8]5,B>9(B<?HLLC__TB%P'0]3(LP08M&#"4`!"``
M/0`$``!THHL]E%P@`.@?R/__3(GVN0(````QTDB)Q^B-Q___2(G&ZX0/'X0`
M`````(L%VFP@`(U0_SGJ#X1_`0``BSU97"``Z.3'__](C355!0``N0,```"Z
M`0```$B)Q^BCQ___2(7`2(G#=#5(BT`0BSTI7"``2(LHZ+''__](C14D!0``
M2(G'2(GNZ!?'__](BT,02(L8]D,.0`^%R@$``(L]^%L@`.B#Q___2(TU^P,`
M`+D#````N@$```!(B<?H0L?__TB%P$B)PW0]2(T]7`,``#'`3(GNZ*'B__](
MA<!(B<4/A%4!``!(BT,0BSVK6R``2(L8Z#/'__](B>I(B<=(B=[HG<;__XL]
MCUL@`.@:Q___2(TUD@0``+H!````2(G'Z!;'__^+/7!;(`!(B</H^,;__TB-
M%84$``!(B=Y(B<?H7L;__XL]4%L@`.C;QO__2(T]S`(``,:`L0````!,B>XQ
MP.@3XO__2(7`2(G#2(D%GFL@``^$D````+[``0``2(G?Z*/%__^-4`&#^@%V
M"8/X$0^%[@```$B+1"0(9$@S!"4H````#X75````2(/$$%M=05Q!74%>PY"#
M^`$/CGC^__^[`0```&:0BSW*6B``@\,!Z%+&__],B>9(B<?H5\7__SD=(6L@
M`'_?Z4O^__]F+@\?A```````@'@!``^$3_W__^E#_?__D$B+/?%J(`#HE/#_
M_TB%P$B)PTB)!>]J(``/A5'___](C3UJ!```,<#H"\;__P\?`$B+!<%J(`"+
M/5-:(`!(BRA(BT,02(L8Z-3%__](B>Y(B=_HR>;__^F?_O__BSTN6B``Z+G%
M__](B=Y(B<?HWL7__^D;_O__Z/S$__^)P4B+!7-J(`!(C3TL!```2(G:2(LP
M,<#HG\7__P\?@`````!54TB)_4B#[`CHHNK__P^V$$B)PX32=!I(C4`!#Q]`
M`(#Z+P^V$$@/1-A(@\`!A-)U[C'`Z)?M__](A>UT'H7`=!J`?0``=!1(C35G
M`@``2(G?Z.G%__](.=AT!TB#Q`A;7<-(@\0(2(GO6UWI_^/__V8N#Q^$````
M```/'T0``$B-!5%9(`!(A<!T#$B+".F,Q/__#Q]``#')Z8'$__^005=!5D&)
M_T%5051,C27N5"``54B-+>Y4(`!328GV28G53"GE2(/L"$C!_0/H7\/__TB%
M[70@,=L/'X0``````$R)ZDR)]D2)_T'_%-Q(@\,!2#GK=>I(@\0(6UU!7$%=
M05Y!7\.09BX/'X0``````//#``!(@^P(2(/$",,````!``(`)7,O)7,`+W!R
M;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%27U!2
M3T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)5
M1P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,
M1%],24)205)97U!!5$@`4TA,24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%
M35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP
M87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE
M=25S`$%21U8`&`!P97)L`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#,T`"UE
M`"TM`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P
M97)L>'-I+F,`````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@
M/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'
M0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@
M*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U
M,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE
M(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R
M(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D
M;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D
M;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA
M<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E
M="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D
M:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F
M9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E
M="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0[
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L
M("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T
M("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6
M>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O
M=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER
M95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@
M)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F
M:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I
M;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO
M9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@
M)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM
M>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@
M)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H
M(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H
M1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H
M<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"([
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO
M=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S
M97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF
M:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F
M:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]
M?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!]
M.PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H
M85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M
M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D
M9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE
M("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@
M>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I
M.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M`````1L#.^0````;````<(+__S`!``!PA/__@`8``'"&__\``0``H(?__U@!
M``#PGO__J`$``,"?__\8`@``0*#__T@"``"0HO__F`(``!"D___@`@``H*3_
M_P`#``!PI?__0`,``*"E__]8`P``\*7__W`#``"PIO__H`,``,"F__^X`P``
MH*C__Q@$``#0J/__,`0``-"I__^`!```\*O__Z@$``!PK/__R`0``*"L___H
M!```(*[__T@%``!PNO__``8``""^__](!@``H+[__[`&``#`OO__R`8``#"_
M__\0!P```````!0``````````7I2``%X$`$;#`<(D`$'$!0````<````:(7_
M_RH``````````````!0``````````7I2``%X$`$;#`<(D`$``"0````<````
M.('__Q``````#A!&#AA*#PMW"(``/QH[*C,D(@````!,````1````$"&__]&
M%P```$(.$(\"0@X8C@-&#B"-!$(.*(P%10XPA@9!#CB#!T<.T`4#'1<*#CA!
M#C!!#BA"#B!"#AA"#A!"#@A!"P```&P```"4````0)W__\H`````2PX0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``G,*#CA#PPXP0<8.*$+,#B!"
MS0X80LX.$$+/#@A*"UP..$'##C!!Q@XH0LP.($+-#AA"S@X00L\."``````L
M````!`$``*"=__]^`````$$.$(8"00X8@P-'#C`";0H.&$$.$$$."$$+````
M``!,````-`$``/"=__])`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+`````$0```"$`0``
M\)___W0!````0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.T`%^"@XP00XH
M00X@0@X80@X00@X(2PL``````!P```#,`0``**'__X$`````00X0@P)I"@X(
M1@L"4`X(/````.P!``"8H?__T`````!"#A"-`D(.&(P#1`X@A@1!#BB#!58.
MP"`"?`H.*$$.($$.&$(.$$(."$<+`````!0````L`@``**+__S``````1`X0
M9PX(`!0```!$`@``0*+__TD`````1`X0?0X(`"P```!<`@``>*+__[D`````
M00X0A@)!#AB#`T<.P$`"GPH.&$$.$$$."$8+`````!0```",`@``"*/__P4`
M`````````````%P```"D`@```*/__]8!````0@X0CP)"#AB.`T(.((T$0@XH
MC`5$#C"&!D$..(,'40[@(`)D"@XX00XP00XH0@X@0@X80@X00@X(00L"F0[H
M($\.\"!Y#N@@00[@(````!0````$`P``@*3__R0``````````````$P````<
M`P``F*3___$`````00X0A@)!#AB#`T0.(`)9"@X800X000X(1PMB"@X82`X0
M00X(30MY"@X82`X000X(1@M$#AA##A!!#@@`````)````&P#``!(I?__$@(`
M``!!#A"#`DL.4`.>`0H.$$$."$4+`````!P```"4`P``0*?__WD`````1`X@
M;PH."$4+````````'````+0#``"@I___)`````!$#A!8"@X(1`L```````!<
M````U`,``+"G__]S`0```$(.$(\"0@X8C@-%#B"-!$(.*(P%2`XPA@9!#CB#
M!TL.H`$"U@H..$$.,$$.*$(.($(.&$(.$$(."$$+:`ZH`4\.L`%Q#J@!00Z@
M`0````"T````-`0``-"H__]$#````$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XP
MA@9!#CB#!TX.P(,"`S,"#LB#`E(.T(,":`[(@P)"#L"#`@)N"@XX00XP00XH
M0@X@0@X80@X00@X(1@L#C0$.R(,"2`[0@P)(#LB#`D$.P(,"9`[(@P)5#M"#
M`D@.V(,"00[@@P)3#L"#`@.\!0[(@P)"#M"#`F@.R(,"00[`@P(#-@$*#LB#
M`D(.T(,"1@L`1````.P$``!HM/__J0,```!"#A".`D(.&(T#0@X@C`1!#BB&
M!4$.,(,&1`Y``ZH""@XP00XH00X@0@X80@X00@X(0@L`````-````#0%``#0
MM___<0````!!#A"&`D$.&(,#1PX@`E<*#AA!#A!!#@A!"T0.&$0.$$$."```
M```L````;`4``.A]___W`0```$$.$(8"00X8@P-$#E`#G`$*#AA!#A!!#@A!
M"P`````4````G`4``.BW__\?``````````````!$````M`4``/"W__]E````
M`$(.$(\"0@X8C@-%#B"-!$(.*(P%2`XPA@9(#CB#!TT.0'(..$$.,$$.*$(.
M($(.&$(.$$(."``4````_`4``!BX__\"````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(`?````````0!\```````````````````$`
M`````````0`````````!`````````-`!`````````0`````````?`@``````
M``P`````````8!H````````-`````````$17````````&0````````#0JR``
M`````!L`````````"``````````:`````````-BK(```````'``````````(
M`````````/7^_V\`````F`(````````%`````````"`-````````!@``````
M``"0`P````````H`````````T`0````````+`````````!@`````````%0``
M``````````````````,`````````R*T@```````'`````````$`3````````
M"``````````@!P````````D`````````&``````````8````````````````
M````^___;P`````!```(`````/[__V\`````P!(```````#___]O``````(`
M````````\/__;P````#P$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````.BK(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````"06@```````$=#
M0SH@*%5B=6YT=2`U+C0N,"TV=6)U;G1U,2D@-2XT+C`@,C`Q-C`V,#D``"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N:6YI=``N<&QT`"YP;'0N9V]T`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````.`(````````X`@```````!P````````````````````!````````
M````````````$P````<````"`````````%0"````````5`(````````@````
M````````````````!````````````````````"$````'`````@````````!T
M`@```````'0"````````)`````````````````````0`````````````````
M```T````]O__;P(`````````F`(```````"8`@```````/0`````````!0``
M```````(````````````````````/@````L````"`````````)`#````````
MD`,```````"0"0````````8````"````"``````````8`````````$8````#
M`````@`````````@#0```````"`-````````T`0```````````````````$`
M``````````````````!.````____;P(`````````\!$```````#P$0``````
M`,P`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````,`2````````P!(```````"```````````8````"````"```````````
M`````````&H````$`````@````````!`$P```````$`3````````(`<`````
M```%``````````@`````````&`````````!T`````0````8`````````8!H`
M``````!@&@```````!H````````````````````$````````````````````
M>@````$````&`````````(`:````````@!H````````0````````````````
M````$``````````0`````````'\````!````!@````````"0&@```````)`:
M````````\`$```````````````````@```````````````````"(`````0``
M``8`````````@!P```````"`'````````,(Z```````````````````0````
M````````````````C@````$````&`````````$17````````1%<````````)
M````````````````````!````````````````````)0````!`````@``````
M``!05P```````%!7````````P$````````````````````@`````````````
M``````"<`````0````(`````````$)@````````0F````````.0`````````
M```````````$````````````````````J@````$````"`````````/B8````
M````^)@```````!$!@``````````````````"````````````````````+0`
M```.`````P````````#0JR```````-"K````````"```````````````````
M``@```````````````````#`````#P````,`````````V*L@``````#8JP``
M``````@````````````````````(````````````````````S`````$````#
M`````````."K(```````X*L````````(````````````````````"```````
M`````````````-$````&`````P````````#HJR```````.BK````````X`$`
M```````&``````````@`````````$`````````"#`````0````,`````````
MR*T@``````#(K0```````#@"```````````````````(``````````@`````
M````V@````$````#``````````"P(````````+`````````@````````````
M````````"````````````````````.`````(`````P`````````@L"``````
M`""P````````B!```````````````````"````````````````````#E````
M`0```#`````````````````````@L````````"P````````````````````!
M``````````$``````````0````,`````````````````````````3+``````
B``#N`````````````````````0``````````````````````
